@@ -1,5 +1,5 @@
 from elody.object_configurations.job_configuration import JobConfiguration
-
+from datetime import datetime, timezone
 
 _config = JobConfiguration()
 _create = _config.crud()["creator"]
@@ -65,7 +65,6 @@ def init_job(
         get_user_context=get_user_context
         or (lambda: type("UserContext", (object,), {"email": user_email})()),
     )
-    del job["computed_values"]["created_at"]
 
     _post_crud_hook(
         crud="create", document=job, parent_id=parent_id, get_rabbit=get_rabbit
@@ -89,6 +88,7 @@ def start_job(
     document = {
         "id": id,
         "patch": {
+            "started_at": datetime.now(timezone.utc),
             "metadata": [{"key": "status", "value": "running"}],
             "relations": ([] if id_of_document_job_was_initiated_for else []),
         },
